class_cups_ppd_printers = \
   ppd/classppd/hpcups/hp-LJ-Class1.ppd.gz \
   ppd/classppd/hpcups/hp-LJ-Class2.ppd.gz \
   ppd/classppd/hpcups/hp-LJ-Class3.ppd.gz \
   ppd/classppd/hpcups/hp-LJ-Class4.ppd.gz \
   ppd/classppd/hpcups/hp-LJ-Class4A.ppd.gz \
   ppd/classppd/hpcups/hp-LJ-Class5.ppd.gz \
   ppd/classppd/hpcups/hp-LJ-Class6.ppd.gz \
   ppd/classppd/hpcups/hp-PCL3-Class1.ppd.gz \
   ppd/classppd/hpcups/hp-PCL3-Class1A.ppd.gz \
   ppd/classppd/hpcups/hp-PCL3-Class1B.ppd.gz \
   ppd/classppd/hpcups/hp-PCL3-Class2.ppd.gz \
   ppd/classppd/hpcups/hp-PCL3-Class3.ppd.gz \
   ppd/classppd/hpcups/hp-PCL3-Class3A.ppd.gz \
   ppd/classppd/hpcups/hp-PCL3-Class3B.ppd.gz \
   ppd/classppd/hpcups/hp-PCL4-Class1.ppd.gz \
   ppd/classppd/hpcups/hp-PCLM.ppd.gz \
   ppd/classppd/ps/hp-postscript-inkjet.ppd.gz \
   ppd/classppd/ps/hp-postscript-laserjet-pro.ppd.gz \
   ppd/classppd/ps/hp-postscript-laserjet.ppd.gz
cups_drv = prnt/drv/hpcups.drv
